@@ -21,7 +21,7 @@ def train(
     evaluation_data: str,
     output_dir: str,
     do_evaluation: str = False,
-    evaluation_output: str = None,
+    evaluation_output: str = 'output',
     qgen_prefix: str = 'qgen',
     base_ckpt: str = 'distilbert-base-uncased',
     generator: str = 'BeIR/query-gen-msmarco-t5-base-v1',
@@ -35,16 +35,20 @@ def train(
     gpl_steps: int = 140000,
     use_amp: bool = False,
     retrievers: List[str] = ['msmarco-distilbert-base-v3', 'msmarco-MiniLM-L-6-v3'],
+    negatives_per_query: int = 50
 ):     
     #### Assertions ####
     assert pooling in ['mean', 'cls', 'max']
     if do_evaluation:
         assert evaluation_data is not None
+        assert evaluation_output is not None
         try:
             GenericDataLoader(evaluation_data)
         except Exception as e:
             logger.error('Cannot load evaluation data for evaluation usage.')
             raise e
+    if new_size is not None:
+        assert new_size * queries_per_passage >= batch_size_gpl
 
     #### Make sure there is a `corpus.jsonl` file. It should be under either `path_to_generated_data` or `evaluation_data`` ####
     #### Also resize the corpus for efficient training if required  ####
@@ -64,7 +68,7 @@ def train(
         logger.info('Loading from existing generated data')
         corpus, gen_queries, gen_qrels = GenericDataLoader(path_to_generated_data, prefix=qgen_prefix).load(split="train")
     else:
-        logger.info('No generated data found. Now generating it')
+        logger.info('No generated queries found. Now generating it')
         assert 'corpus.jsonl' in os.listdir(path_to_generated_data), 'At least corpus should exist!'
         qgen(path_to_generated_data, path_to_generated_data, generator_name_or_path=generator, ques_per_passage=queries_per_passage, bsz=batch_size_generation, qgen_prefix=qgen_prefix)
         corpus, gen_queries, gen_qrels = GenericDataLoader(path_to_generated_data, prefix=qgen_prefix).load(split="train")
@@ -75,15 +79,15 @@ def train(
         logger.info('Using exisiting hard-negative data')
     else: 
         logger.info('No hard-negative data found. Now mining it')
-        miner = NegativeMiner(path_to_generated_data, qgen_prefix, retrievers=retrievers)
+        miner = NegativeMiner(path_to_generated_data, qgen_prefix, retrievers=retrievers, nneg=negatives_per_query)
         miner.run()
 
     #### Pseudo labeling ####
     #### This will be skipped if there is an existing `gpl-training-data.tsv` file under `path_to_generated_data` ####
     if 'gpl-training-data.tsv' in os.listdir(path_to_generated_data):
-        logger.info('Using existing GPL training data')
+        logger.info('Using existing GPL-training data')
     else:
-        logger.info('No GPL training data found. Now generating it via pseudo labeling')
+        logger.info('No GPL-training data found. Now generating it via pseudo labeling')
         pseudo_labeler = PseudoLabeler(path_to_generated_data, gen_queries, corpus, gpl_steps, batch_size_gpl, cross_encoder)
         pseudo_labeler.run()
     
@@ -138,7 +142,7 @@ if __name__ == '__main__':
     parser.add_argument('--evaluation_data', required=True, help='Path to the BeIR-format dataset. Please make sure at least `corpus.jsonl` exists under this path, which will be used for GPL training.')
     parser.add_argument('--output_dir', required=True, help='Output path for the GPL model.')
     parser.add_argument('--do_evaluation', action='store_true', default=False, help='Wether to do the evaluation (after training)')
-    parser.add_argument('--evaluation_output', required=True, help='Path for the evaluation output.')
+    parser.add_argument('--evaluation_output', default='output', help='Path for the evaluation output.')
     parser.add_argument('--qgen_prefix', default='qgen', help='This prefix will appear as part of the (folder/file) names for query-generation results: For example, we will have "gen-qrels/" and "gen-queries.jsonl" by default.')
     parser.add_argument('--base_ckpt', default='distilbert-base-uncased', help='Initialization checkpoint in HF or SBERT format. Meaning-pooling will be used.')
     parser.add_argument('--generator', default='BeIR/query-gen-msmarco-t5-base-v1')
@@ -152,5 +156,6 @@ if __name__ == '__main__':
     parser.add_argument('--gpl_steps', type=int, default=140000, help='Training steps for GPL.')
     parser.add_argument('--use_amp', action='store_true', default=False, help='Whether to use half precision')
     parser.add_argument('--retrievers', nargs='+', default=['msmarco-distilbert-base-v3', 'msmarco-MiniLM-L-6-v3'], help='Indicate retriever names. They could be one or many BM25 ("bm25") or dense retrievers (in SBERT format).')
+    parser.add_argument('--negatives_per_query', type=int, default=50, help="Mine how many negatives per query per retriever")
     args = parser.parse_args()
     train(**vars(args))
\ No newline at end of file
